@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2020-2025, by Samuel Williams.
+# Copyright, 2020-2026, by Samuel Williams.
 
 module Async
 	module Container
@@ -17,6 +17,12 @@ module Async
 					send(ready: true, **message)
 				end
 				
+				# Notify the parent controller that the child is healthy.
+				# @parameters message [Hash] Additional details to send with the message.
+				def healthy!(**message)
+					send(healthy: true, **message)
+				end
+				
 				# Notify the parent controller that the child is reloading.
 				# @parameters message [Hash] Additional details to send with the message.
 				def reloading!(**message)
